@@ -68,13 +68,14 @@ class Encoder(torch.nn.Module):
         self.output_dim = output_dim
         self.num_latlons = len(lat_lons)
         self.base_h3_grid = sorted(list(h3.uncompact(h3.get_res0_indexes(), resolution)))
+        self.base_h3_map = {h_i: i for i, h_i in enumerate(self.base_h3_grid)}
         self.h3_grid = [h3.geo_to_h3(lat, lon, resolution) for lat, lon in lat_lons]
         self.h3_mapping = {}
-        h_index = 0
+        h_index = len(self.base_h3_grid)
         for h in self.base_h3_grid:
             if h not in self.h3_mapping:
+                h_index -= 1
                 self.h3_mapping[h] = h_index + self.num_latlons
-                h_index += 1
         # Now have the h3 grid mapping, the bipartite graph of edges connecting lat/lon to h3 nodes
         # Should have vertical and horizontal difference
         self.h3_distances = []
@@ -86,7 +87,7 @@ class Encoder(torch.nn.Module):
         # Compress to between 0 and 1
 
         # Build the default graph
-        # lat_nodes = torch.zeros((len(lat_lons), input_dim), dtype=torch.float)
+        # lat_nodes = torch.zeros((len(lat_lons_heights), input_dim), dtype=torch.float)
         # h3_nodes = torch.zeros((h3.num_hexagons(resolution), output_dim), dtype=torch.float)
         nodes = torch.zeros(
             (len(lat_lons) + h3.num_hexagons(resolution), input_dim), dtype=torch.float
@@ -151,6 +152,7 @@ class Encoder(torch.nn.Module):
             Torch tensors of node features, latent graph edge index, and latent edge attributes
         """
         batch_size = features.shape[0]
+        self.h3_nodes = self.h3_nodes.to(features.device)
         features = torch.cat(
             [features, einops.repeat(self.h3_nodes, "n f -> b n f", b=batch_size)], dim=1
         )
@@ -198,13 +200,13 @@ class Encoder(torch.nn.Module):
         edge_sources = []
         edge_targets = []
         edge_attrs = []
-        for h3_index in self.h3_mapping.keys():
+        for h3_index in self.base_h3_grid:
             h_points = h3.k_ring(h3_index, 1)
             for h in h_points:  # Already includes itself
                 distance = h3.point_dist(h3.h3_to_geo(h3_index), h3.h3_to_geo(h), unit="rads")
                 edge_attrs.append([np.sin(distance), np.cos(distance)])
-                edge_sources.append(self.h3_mapping[h3_index] - self.num_latlons)
-                edge_targets.append(self.h3_mapping[h] - self.num_latlons)
+                edge_sources.append(self.base_h3_map[h3_index])
+                edge_targets.append(self.base_h3_map[h])
         edge_index = torch.tensor([edge_sources, edge_targets], dtype=torch.long)
         edge_attrs = torch.tensor(edge_attrs, dtype=torch.float)
         # Use heterogeneous graph as input and output dims are not same for the encoder
